/*
 * metismenu - v2.0.3
 * A jQuery menu plugin
 * https://github.com/onokumus/metisMenu
 *
 * Made by Osman Nuri Okumus
 * Under MIT License
 */

(function($) {
    'use strict';

    function transitionEnd() {
        var el = document.createElement('mm');

        var transEndEventNames = {
            WebkitTransition: 'webkitTransitionEnd',
            MozTransition: 'transitionend',
            OTransition: 'oTransitionEnd otransitionend',
            transition: 'transitionend'
        };

        for (var name in transEndEventNames) {
            if (el.style[name] !== undefined) {
                return {
                    end: transEndEventNames[name]
                };
            }
        }
        return false;
    }

    $.fn.emulateTransitionEnd = function(duration) {
        var called = false;
        var $el = this;
        $(this).one('mmTransitionEnd', function() {
            called = true;
        });
        var callback = function() {
            if (!called) {
                $($el).trigger($transition.end);
            }
        };
        setTimeout(callback, duration);
        return this;
    };

    var $transition = transitionEnd();
    if (!!$transition) {
        $.event.special.mmTransitionEnd = {
            bindType: $transition.end,
            delegateType: $transition.end,
            handle: function(e) {
                if ($(e.target).is(this)) {
                    return e.
                    handleObj.
                    handler.
                    apply(this, arguments);
                }
            }
        };
    }

    var MetisMenu = function(element, options) {
        this.$element = $(element);
        this.options = $.extend({}, MetisMenu.DEFAULTS, options);
        this.transitioning = null;

        this.init();
    };

    MetisMenu.TRANSITION_DURATION = 350;

    MetisMenu.DEFAULTS = {
        toggle: true,
        doubleTapToGo: false,
        activeClass: 'active',
        collapseClass: 'collapse',
        collapseInClass: 'in',
        collapsingClass: 'collapsing'
    };

    MetisMenu.prototype.init = function() {
        var $this = this;
        var activeClass = this.options.activeClass;
        var collapseClass = this.options.collapseClass;
        var collapseInClass = this.options.collapseInClass;

        this
            .$element
            .find('li.' + activeClass)
            .has('ul')
            .children('ul')
            .addClass(collapseClass + ' ' + collapseInClass);

        this
            .$element
            .find('li')
            .not('.' + activeClass)
            .has('ul')
            .children('ul')
            .addClass(collapseClass);

        //add the 'doubleTapToGo' class to active items if needed
        if (this.options.doubleTapToGo) {
            this
                .$element
                .find('li.' + activeClass)
                .has('ul')
                .children('a')
                .addClass('doubleTapToGo');
        }

        this
            .$element
            .find('li')
            .has('ul')
            .children('a')
            .on('click.metisMenu', function(e) {
                var self = $(this);
                var $parent = self.parent('li');
                var $list = $parent.children('ul');
                e.preventDefault();

                if ($parent.hasClass(activeClass) && !$this.options.doubleTapToGo) {
                    $this.hide($list);
                } else {
                    $this.show($list);
                }

                //Do we need to enable the double tap
                if ($this.options.doubleTapToGo) {
                    //if we hit a second time on the link and the href is valid, navigate to that url
                    if ($this.doubleTapToGo(self) && self.attr('href') !== '#' && self.attr('href') !== '') {
                        e.stopPropagation();
                        document.location = self.attr('href');
                        return;
                    }
                }
            });
    };

    MetisMenu.prototype.doubleTapToGo = function(elem) {
        var $this = this.$element;
        //if the class 'doubleTapToGo' exists, remove it and return
        if (elem.hasClass('doubleTapToGo')) {
            elem.removeClass('doubleTapToGo');
            return true;
        }
        //does not exists, add a new class and return false
        if (elem.parent().children('ul').length) {
            //first remove all other class
            $this
                .find('.doubleTapToGo')
                .removeClass('doubleTapToGo');
            //add the class on the current element
            elem.addClass('doubleTapToGo');
            return false;
        }
    };

    MetisMenu.prototype.show = function(el) {
        var activeClass = this.options.activeClass;
        var collapseClass = this.options.collapseClass;
        var collapseInClass = this.options.collapseInClass;
        var collapsingClass = this.options.collapsingClass;
        var $this = $(el);
        var $parent = $this.parent('li');
        if (this.transitioning || $this.hasClass(collapseInClass)) {
            return;
        }

        $parent.addClass(activeClass);

        if (this.options.toggle) {
            this.hide($parent.siblings().children('ul.' + collapseInClass));
        }

        $this
            .removeClass(collapseClass)
            .addClass(collapsingClass)
            .height(0);

        this.transitioning = 1;
        var complete = function() {
            $this
                .removeClass(collapsingClass)
                .addClass(collapseClass + ' ' + collapseInClass)
                .height('');
            this.transitioning = 0;
        };
        if (!$transition) {
            return complete.call(this);
        }
        $this
            .one('mmTransitionEnd', $.proxy(complete, this))
            .emulateTransitionEnd(MetisMenu.TRANSITION_DURATION)
            .height($this[0].scrollHeight);
    };

    MetisMenu.prototype.hide = function(el) {
        var activeClass = this.options.activeClass;
        var collapseClass = this.options.collapseClass;
        var collapseInClass = this.options.collapseInClass;
        var collapsingClass = this.options.collapsingClass;
        var $this = $(el);

        if (this.transitioning || !$this.hasClass(collapseInClass)) {
            return;
        }

        $this.parent('li').removeClass(activeClass);
        $this.height($this.height())[0].offsetHeight;

        $this
            .addClass(collapsingClass)
            .removeClass(collapseClass)
            .removeClass(collapseInClass);

        this.transitioning = 1;

        var complete = function() {
            this.transitioning = 0;
            $this
                .removeClass(collapsingClass)
                .addClass(collapseClass);
        };

        if (!$transition) {
            return complete.call(this);
        }
        $this
            .height(0)
            .one('mmTransitionEnd', $.proxy(complete, this))
            .emulateTransitionEnd(MetisMenu.TRANSITION_DURATION);
    };

    function Plugin(option) {
        return this.each(function() {
            var $this = $(this);
            var data = $this.data('mm');
            var options = $.extend({},
                MetisMenu.DEFAULTS,
                $this.data(),
                typeof option === 'object' && option
            );

            if (!data) {
                $this.data('mm', (data = new MetisMenu(this, options)));
            }
            if (typeof option === 'string') {
                data[option]();
            }
        });
    }

    var old = $.fn.metisMenu;

    $.fn.metisMenu = Plugin;
    $.fn.metisMenu.Constructor = MetisMenu;

    $.fn.metisMenu.noConflict = function() {
        $.fn.metisMenu = old;
        return this;
    };

})(jQuery);

$(function() {

    $('#sidebar-menu, #customize-menu').metisMenu({
        activeClass: 'open'
    });


    $('#sidebar-collapse-btn').on('click', function(event) {
        event.preventDefault();

        $("#app").toggleClass("sidebar-open");
    });

    $("#sidebar-overlay").on('click', function() {
        $("#app").removeClass("sidebar-open");
    });

});
var modalMedia = {
    $el: $("#modal-media"),
    result: {},
    options: {},
    open: function(options) {
        options = options || {};
        this.options = options;


        this.$el.modal('show');
    },
    close: function() {
        if ($.isFunction(this.options.beforeClose)) {
            this.options.beforeClose(this.result);
        }

        this.$el.modal('hide');

        if ($.isFunction(this.options.afterClose)) {
            this.options.beforeClose(this.result);
        }
    }
};
$(function() {
    $('.nav-profile > li > a').on('click', function() {
        var $el = $(this).next();

        animate({
            name: 'flipInX',
            selector: $el
        });
    });
})
$(function() {

    // Local storage settings
    var themeSettings = getThemeSettings();

    // Elements

    var $app = $('#app');
    var $styleLink = $('#theme-style');
    var $customizeMenu = $('#customize-menu');

    // Color switcher
    var $customizeMenuColorBtns = $customizeMenu.find('.color-item');

    // Position switchers
    var $customizeMenuRadioBtns = $customizeMenu.find('.radio');



    /************************************************
     *			Update theme based on options
     *************************************************/

    function setThemeState() {
        // set theme type
        if (themeSettings.themeName) {
            $styleLink.attr('href', 'css/app-' + themeSettings.themeName + '.css');
        } else {
            $styleLink.attr('href', 'css/app.css');
        }

        // App classes
        $app.removeClass('header-fixed footer-fixed sidebar-fixed');

        // set header
        $app.addClass(themeSettings.headerPosition);

        // set footer
        $app.addClass(themeSettings.footerPosition);

        // set footer
        $app.addClass(themeSettings.sidebarPosition);

        return $app;
    }

    /************************************************
     *			Update theme controls based on options
     *************************************************/

    function setThemeControlsState() {
        // set color switcher
        $customizeMenuColorBtns.each(function() {
            if ($(this).data('theme') === themeSettings.themeName) {
                $(this).addClass('active');
            } else {
                $(this).removeClass('active');
            }
        });

        // set radio buttons
        $customizeMenuRadioBtns.each(function() {
            var name = $(this).prop('name');
            var value = $(this).val();

            if (themeSettings[name] === value) {
                $(this).prop("checked", true);
            } else {
                $(this).prop("checked", false);
            }
        });
    }



    function getThemeSettings() {
        var settings = (localStorage.getItem('themeSettings')) ? JSON.parse(localStorage.getItem('themeSettings')) : {};

        settings.headerPosition = settings.headerPosition || '';
        settings.sidebarPosition = settings.sidebarPosition || '';
        settings.footerPosition = settings.footerPosition || '';

        return settings;
    }

    function saveThemeSettings() {
        localStorage.setItem('themeSettings', JSON.stringify(themeSettings));
    }

});
$(function() {

    $("body").addClass("loaded");

});